function GenBoot_SMBvar()%phi,ts,dx,smbs)

% GenBootFile_IceStream_ideal_v2  Creates "from scratch" a dataset with the right format
% to use as a PISM bootstrapping file.  Example use of Matlab for this purpose.
% Based on the pism_matlab script included in PISM utils
%
% Usage, including a minimal PISM call to bootstrap from this file:
%    $ matlab
%    >> GenBootFile_IceStream_ideal_v2  % creates filename.nc
%    >> exit
%    $ pismr -boot_file bar.nc -Mx 41 -My 41 -Mz 21 -Lz 4000 -Mbz 5 -Lbz 500 -y 1

% Add parameters in the function

dx = 20e3;
ts = 0; %ice surface temperature celsius
phi = 10; % Minimum till friction angle
smbs = 10;


% set up the grid:
Lx = 9000e3;
Ly = 7000e3;
%nstrips = 56;

Mx = Lx/dx + 1;
My = Ly/dx + 1;
x = linspace(-5000e3,4000e3,Mx);
y = linspace(-7200e3,-200e3,My);

% create dummy fields
[xx,yy] = meshgrid(x,y);  % meshgrid() generates wrong ordering

% Write rectangular topography of polar stereographic map
format long;
[Lon_geo,Lat_geo] = textread('Lat_Lon_Gowan_6f.txt','%q %q');
Lat_geo01 = char(Lat_geo);
Lon_geo01 = char(Lon_geo);
Lat_geo0 = str2num(Lat_geo01);
Lon_geo0 = str2num(Lon_geo01);
Lat_G=reshape(Lat_geo0,364,499);
Lon_G=reshape(Lon_geo0,364,499);

[Lon00,Lat00] = textread('Lat_Lon.txt','%q %q');
Lat01 = char(Lat00);
Lon01 = char(Lon00);
Lat0 = str2num(Lat01);
Lon0 = str2num(Lon01);
%Lon=Lat_Lon(:,1);
Lat=reshape(Lat0,My,Mx);
Lon=reshape(Lon0,My,Mx);
Lat_grid=Lat;
Lon_grid=Lon;
topo0= ncread('etopo2.nc','topo');
lat0 = ncread('etopo2.nc','lat');
lon0 = ncread('etopo2.nc','lon');
topo_PISM=zeros(My,Mx);
for i=1:Mx
   for j=1:My
      [~,ii]= min(abs(lat0(:)-Lat_grid(j,i)));
      [~,jj]= min(abs(lon0(:)-Lon_grid(j,i)));
      topo_PISM(j,i)=topo0(jj,ii);
   end
end


% Use Three points to erase Grennland and other useless topography
% Point 1 lies in Baffin Bay
% Point 2 lies in Top
% Point 3 lies in Bottom
P_1x = 270;
P_1y = 286;

P_2x = 275;
P_2y = 344;

P_3x = 359;
P_3y = 221;

k1 = (P_2y-P_1y)/(P_2x-P_1x);
k2 = (P_3y-P_1y)/(P_3x-P_1x);

for j=P_3y:1:P_1y
   for i=P_1x:1:Mx
       if (j>k2*(i-P_1x)+P_1y)  & (topo_PISM(j,i)>-1000) %& (topo_PISM(j,i)<=1000) & (i<=345)% & (topo_PISM(j,i)>topo_PISM(j,i-1))
          topo_PISM(j,i)=-1000;%-topo_PISM(j,i); %topo_PISM(j,i)=-1000; %
%       elseif (j>k2*(i-P_1x)+P_1y) & (topo_PISM(j,i)>-1000)
%          topo_PISM(j,i)=-1000;
       end
       
   end
    
    
end

for j=P_1y:1:My
   for i=P_1x:1:Mx
      if (j<k1*(i-P_1x)+P_1y) & (topo_PISM(j,i)>-1000) %& (topo_PISM(j,i)<=1000) & (i<=300)
          topo_PISM(j,i)=-1000;%-topo_PISM(j,i); %topo_PISM(j,i)=-1000;%
%       elseif (j<k1*(i-P_1x)+P_1y) & (topo_PISM(j,i)>-1000)
%              topo_PISM(j,i)=-1000;
      end
   end
    
end

N_Bound = My-20;

for j=N_Bound:1:My
   for i=1:1:Mx
      if topo_PISM(j,i)>-1000
          topo_PISM(j,i)=-1000;
      end
   end
end

topo_LIS=topo_PISM;%(50:400,1:451);
Lat_LIS =Lat_grid;%(50:400,1:451);
Lon_LIS =Lon_grid;%(50:400,1:451);


topg=topo_LIS';
lat =Lat_LIS';
lon =Lon_LIS';

% acab = zeros(Mx,My) + (0.3*917);

% Write surface temperature 

%T_lat0=linspace(12,-5.15,My);  % ST from 40N to 85N
T_lat0=linspace(19.5,-6.5,2301)-5;  % ST from 20N to 89N, every 0.03 degree
lat_t = linspace(20,89,2301);
T_latlon=zeros(My,Mx);

for i=1:Mx
   for j=1:My
      [~,Ti]= min(abs(lat_t(:)-Lat_LIS(j,i)));
      T_latlon(j,i)=T_lat0(Ti);
   end
end

%T_latlon = repmat(T_lat0,Mx,1);


ist_anom = T_latlon ;
ist_anom=ist_anom';
artm = ist_anom;

% SMB anomaly -1000 at 35N to 500 at 85N
%smb_south = linspace(-1000,500,My);

% SMB anomaly -1450 at 20N to 620 at 89N
smb_south= linspace(-1450,620,2301);
lat_SMB  = linspace(20,89,2301);
smb_anom = zeros(My,Mx);

for i=1:Mx
   for j=1:My
      smb_anom(j,i)=-5*1000^(-Lat_LIS(j,i)/5+10)+5;
       %[~,Ti]= min(abs(lat_SMB(:)-Lat_LIS(j,i)));
      %smb_anom(j,i)=smb_south(Ti);
      if Lat_LIS(j,i)<45
          smb_anom(j,i)=-5000;
      end
      if Lat_LIS(j,i)>=50
          smb_anom(j,i)=0;
      end
      
   end
end


%smb_south(1:10) = -5000;


smb_anom = smb_anom';

acab = smb_anom;

  thk = zeros(size(smb_anom));
 
% Initial topography by Alex 
% topg = zeros(My,Mx);
% topg(yy<=600e3) = 100.*(1 - ((xx(yy<=600e3)-(x_cent))/2e6).^8);
% topg(yy>600e3) = 100.*(1 - (dist_from_xcent(yy>600e3)/2e6).^8);
% topg = topg - 1500.*(tanh((xx-100e3)./1e5)-1);
% topg = topg - 40.*(sin(2*pi*xx./300e3)+1).*exp(-(yy./500e3).^2);
% topg=topg';

bhf = zeros(Mx,My)+0.01; % 30 milliwatts basal heat flux
% bhf(:,1:(My-9)/2) = 0.07;
% bhf(:,My-(My-9)/2+1:My) = 0.2;
% bhf(:,(My-9)/2+1:My-(My-9)/2) = repmat(linspace(0.07,0.2,9),[Mx 1]);

tillwat = zeros(Mx,My);
bwat = zeros(Mx,My);

%% Set tillphi strips
dx = round(Lx/(Mx-1));
phi_min = phi;
phi_max = 30; % Change phi_max from 80 to 89

%Initial tillphi by Alex
%strip_width = 80e3;
% phimin_strips_rad = phi_max.*ones(My,Mx);
% thetas = linspace(0,2*pi,nstrips+1);
% for ntheta = 1:nstrips
%     for dist_out = linspace(0,sqrt((Lx^2)/2),Mx)
%        xstr = dist_out*sin(thetas(ntheta));
%        ystr = dist_out*cos(thetas(ntheta));
%        [i,j] = find(abs(xx-(x_cent)-xstr)<=strip_width/2 & abs(yy-(Ly/4)-ystr)<=strip_width/2);
%        phimin_strips_rad(i,j) = phi_min;
%    end
% end
% 
% phimin_strips_sq = 35*square(2*pi*x/160e3)+45;
% phimin_strips_sq = repmat(phimin_strips_sq,[My 1]);

% Add till friction angle from Laske & Masters (1997)
% A cutoff value of 5 (11 and 89 degrees). Weiwen Ji

% Need to import sediment data (sedmap.gmt) manually.
% sedmap  = readtable('sedmap.dat');
% dat_LIS = sedmap((sedmap.Var1<-45) & (sedmap.Var2>34) & (sedmap.Var2<85),:);
% Lon_sed = dat_LIS(1:135,1);
% Lat_sed = dat_LIS(dat_LIS.Var1==-179.5,2);
% sed_LIS = zeros(length(table2array(Lat_sed)),length(table2array(Lon_sed)));
% Lon_sed = table2array(Lon_sed);
% Lat_sed = table2array(Lat_sed);
% dat_LIS = table2array(dat_LIS);
geomap0  = ncread('geology.nc','merge_geo_holes6_lam_Polygon');
geomap = zeros(364,499); % dx=dy=20km
for j=1:364
   for i=1:499
       i0=4*i-3;
       j0=1457-4*j;
      geomap(j,i)=geomap0(i0,j0); 
      if geomap(j,i)==255
          geomap(j,i)=0.0;
      end
   end
end

geo_PISM=zeros(My,Mx);
for i=1:Mx
   for j=1:My
       A_m =abs(Lat_G-Lat_LIS(j,i)) + abs(Lon_G-Lon_LIS(j,i));
       [Ss,~] = min(min(A_m));
   %    [~,Sj]= min(min(abs(Lat_G-Lat_LIS(j,i))));
   %    [~,Si]= min(min(abs(Lon_G-Lon_LIS(j,i))));
       [yyy,xxx]=find(A_m==Ss);
       geo_PISM(j,i)=geomap(yyy,xxx);
   end
end

till_geo = 10.0*ones(Mx,My);
for i=1:Mx
   for j=1:My
       if geo_PISM(j,i)==6
           till_geo(i,j)=30;
       elseif geo_PISM(j,i)==4
           till_geo(i,j)=25;
       elseif (geo_PISM(j,i)<4) & (geo_PISM(j,i)>0)
           till_geo(i,j)=20;
       elseif geo_PISM(j,i)==0
           till_geo(i,j)=10;
       end
   end 
end

%sedmap  = load('sedmap.dat');
%dat_LIS = sedmap((sedmap(:,1)<-1) &  (sedmap(:,2)>20) & (sedmap(:,2)<89),:);
%Lon_sed = dat_LIS(1:179,1);
%Lat_sed = dat_LIS(dat_LIS(:,1)==-179.5,2);
%sed_LIS = zeros(length(Lat_sed),length(Lon_sed));
%sed_LIS = sed_LIS';
%  for j=1:69
%      for i=1:179
%          tt = i+179*(j-1);
%          sed_LIS(70-j,i) =dat_LIS(tt,3);
%      end      
%  end
% Lon_sed=Lon_sed+360;
% [LAT,LON]=ndgrid(Lat_sed,Lon_sed);

% sed_PISM=zeros(My,Mx);
% for i=1:Mx
%    for j=1:My
%        [~,Si]= min(abs(Lat_sed(:)-Lat_LIS(j,i)));
%        [~,Sj]= min(abs(Lon_sed(:)-Lon_LIS(j,i)));
%        Sed_i=70-Si;
%        sed_PISM(j,i)=sed_LIS(Sed_i,Sj);
%    end
% end

%%% max sediment depth  is 12.75 m or km?

%%% 0.05  equals 40 degree.
%%% 12.75 equals 5  degree.
%%% changing linearly in between.
%k_till = (phi_min-phi_max)/(12.75-0.05);


tillphi = till_geo;% phi_min.*ones(Mx,My);
%tillphi(dist_from_xcent>1900e3) = phimin_strips(dist_from_xcent>1900e3);

% for i=1:Mx
%    for j=1:My
%       if sed_PISM(j,i)<0.05
%           tillphi(i,j)=30;
%       elseif (sed_PISM(j,i)>=0.05) & (sed_PISM(j,i)<10)
%           tillphi(i,j)=20;
%       elseif sed_PISM(j,i)>=10
%           tillphi(i,j)=10;
%           
%       end
%       
%        
%    end
% end
% 
% for j=P_3y:1:P_1y
%    for i=P_1x:1:Mx
%        if (j>k2*(i-P_1x)+P_1y) & (tillphi(i,j)>20)% & (topo_PISM(j,i)<=300)
%           tillphi(i,j)=20; %topo_PISM(j,i)=-topo_PISM(j,i);
%     %   elseif (j>k2*(i-P_1x)+P_1y) & (topo_PISM(j,i)>300)
%      %      topo_PISM(j,i)=-300;
%        end
%        
%    end
%     
%     
% end
% 
% for j=P_1y:1:My
%    for i=P_1x:1:Mx
%       if (j<k1*(i-P_1x)+P_1y) & (tillphi(i,j)>20) %& (topo_PISM(j,i)<=300)
%           tillphi(i,j)=20;%-topo_PISM(j,i);
% %       elseif (j<k1*(i-P_1x)+P_1y) & (topo_PISM(j,i)>300)
% %              topo_PISM(j,i)=-300;
%       end
%    end
%     
% end

%tillphi = tillphi';
%tillphi(dist_from_xcent>1800e3 & yy > 1100e3) = phimin_strips_rad(dist_from_xcent>1800e3 & yy > 1100e3);
%tillphi(dist_from_xcent>2500e3 & yy > 1100e3) = phi_min;
%tillphi(yy<1000e3) = phi_min;

%boundary conditions
%bcflag = zeros(Mx,My);
% bcflag(1,:) = 1;    %dirichlet bc upstream
% bcflag(:,1) = 1;    %dirichlet bc side 1
 %bcflag(:,end) = 1;  %dirichlet bc side 2

%u_bc = zeros(Mx,My);
%v_bc = zeros(Mx,My);

%% Set forcing variables

% create a file; NC_CLOBBER means "overwrite if exists"
%ncid = netcdf.create(['CS_boot_regrid_phi',num2str(phi),'_ts',int2str(ts),'_dx',int2str(dx),'_smbs',num2str(smbs),'.nc'], 'NC_CLOBBER');
% Remove SMB, Weiwen Ji
ncid = netcdf.create(['CS_proj4_Gowan_T_5less_bht0.01_phi',num2str(phi),'to',num2str(phi_max),'_ts',int2str(ts),'_dx',int2str(dx),'.nc'], 'NC_CLOBBER');

% create global proj4
proj4_id = netcdf.getConstant('NC_GLOBAL');
netcdf.putAtt(ncid,proj4_id,'proj4','+proj=stere +lat_0=90 +lat_ts=90 +lon_0=-90 +k=1 +x_0=0 +y_0=0 +ellps=WGS84 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs');


% create dimensions:
x_id = netcdf.defDim(ncid, 'x', Mx);
y_id = netcdf.defDim(ncid, 'y', My);
%map_id = netcdf.defDim(ncid,'mapping', []);

% create coordinate variables:
x_var_id = netcdf.defVar(ncid, 'x', 'float', [x_id]);
y_var_id = netcdf.defVar(ncid, 'y', 'float', [y_id]);
mapid    = netcdf.defVar(ncid, 'mapping','NC_CHAR',[]);
%timeid   = netcdf.defVar(ncid, 'time', 'float', []);

% create variables corresponding to spatial fields:
% dimension transpose is standard: "float thk(y, x)" in NetCDF file
topg_id = netcdf.defVar(ncid, 'topg', 'float', [x_id,y_id]);
thk_id  = netcdf.defVar(ncid, 'thk',  'float', [x_id,y_id]);
%acab_id = netcdf.defVar(ncid, 'climatic_mass_balance', 'double', [x_id,y_id]);
%artm_id = netcdf.defVar(ncid, 'ice_surface_temp', 'float', [x_id,y_id]);
bhf_id =  netcdf.defVar(ncid, 'bheatflx', 'float', [x_id,y_id]);
%tillwat_id = netcdf.defVar(ncid, 'tillwat', 'float', [x_id,y_id]);
tillphi_id = netcdf.defVar(ncid, 'tillphi', 'float', [x_id,y_id]);
%bcflag_id = netcdf.defVar(ncid, 'bcflag', 'float', [x_id,y_id]);
%ubc_id = netcdf.defVar(ncid, 'u_ssa_bc', 'float', [x_id,y_id]);
%vbc_id = netcdf.defVar(ncid, 'v_ssa_bc', 'float', [x_id,y_id]);
%bwat_id = netcdf.defVar(ncid, 'bwat','float', [x_id,y_id]);
cmba_id = netcdf.defVar(ncid, 'climatic_mass_balance_anomaly','float', [x_id,y_id]);
ista_id = netcdf.defVar(ncid, 'ice_surface_temp_anomaly','float', [x_id,y_id]);

lat_id = netcdf.defVar(ncid,'lat','float',[x_id,y_id]);
lon_id = netcdf.defVar(ncid,'lon','float',[x_id,y_id]);

% done defining dimensions and variables:
netcdf.endDef(ncid);

% write coordinate variables:
netcdf.putVar(ncid, x_var_id, x);
netcdf.putVar(ncid, y_var_id, y);

% surface temperature:
%netcdf.putVar(ncid, artm_id, artm);

% accumulation/ablation rate:
%netcdf.putVar(ncid, acab_id, acab);


% climatic mass balance and ice temp anomaly at surface:
netcdf.putVar(ncid, cmba_id, smb_anom);
netcdf.putVar(ncid, ista_id, ist_anom);

% bedrock elevation:
netcdf.putVar(ncid, topg_id, topg);

% ice thickness:
netcdf.putVar(ncid, thk_id, thk);

% till water thickness:
%netcdf.putVar(ncid, tillwat_id, tillwat);

% tillphi:
netcdf.putVar(ncid, tillphi_id, tillphi);

% basal heat flux:
netcdf.putVar(ncid, bhf_id, bhf);

% basal water layer
%netcdf.putVar(ncid, bwat_id, bwat); 

% boundary conditions:
%netcdf.putVar(ncid, bcflag_id, bcflag);
%netcdf.putVar(ncid, ubc_id, u_bc);
%netcdf.putVar(ncid, vbc_id, v_bc);

% Add Latitude and Longitude by Weiwen Ji 11/2/2018


netcdf.putVar(ncid,lat_id,lat);
netcdf.putVar(ncid,lon_id,lon);

% Re-enter define mode 
netcdf.reDef(ncid);

% create mapping
netcdf.putAtt(ncid,mapid,'ellipsoid','WGS84');
netcdf.putAtt(ncid,mapid,'false_easting',0.0);
netcdf.putAtt(ncid,mapid,'false_northing',0.0);
netcdf.putAtt(ncid,mapid,'grid_mapping_name','polar_stereographic');
netcdf.putAtt(ncid,mapid,'latitude_of_projection_origin',90.0);
netcdf.putAtt(ncid,mapid,'standard_parallel',90.0);
netcdf.putAtt(ncid,mapid,'straight_vertical_longitude_from_pole',-90.0);
netcdf.putAtt(ncid,mapid,'_CoordinateTransformType','Projection');
netcdf.putAtt(ncid,mapid,'_CoordinateAxisTypes','GeoX GeoY');


% write attributes:
netcdf.putAtt(ncid, x_var_id, 'long_name', 'Cartesian x-coordinate');
netcdf.putAtt(ncid, x_var_id, 'standard_name', 'projection_x_coordinate');
netcdf.putAtt(ncid, x_var_id, 'units', 'meters')
netcdf.putAtt(ncid, y_var_id, 'long_name', 'Cartesian y-coordinate');
netcdf.putAtt(ncid, y_var_id, 'standard_name', 'projection_y_coordinate');
netcdf.putAtt(ncid, y_var_id, 'units', 'meters');



% write attributes:
netcdf.putAtt(ncid, topg_id, 'grid_mapping', 'mapping');
netcdf.putAtt(ncid, topg_id, 'long_name', 'Bedrock Topography');
netcdf.putAtt(ncid, topg_id, 'standard_name', 'bedrock_altitude');
netcdf.putAtt(ncid, topg_id, 'units', 'meters');
netcdf.putAtt(ncid, thk_id, 'grid_mapping', 'mapping');
netcdf.putAtt(ncid, thk_id, 'long_name', 'Ice Thickness');
netcdf.putAtt(ncid, thk_id, 'standard_name', 'land_ice_thickness');
netcdf.putAtt(ncid, thk_id, 'units', 'meters');

%netcdf.putAtt(ncid, acab_id, 'units', 'kg m-2 year-1');
%netcdf.putAtt(ncid, acab_id, 'standard_name', 'land_ice_surface_specific_mass_balance');
%netcdf.putAtt(ncid, acab_id, 'grid_mapping', 'mapping');
%netcdf.putAtt(ncid, acab_id, 'long_name', 'Surface Mass Balance');
%netcdf.putAtt(ncid, acab_id, 'standard_name', 'land_ice_surface_specific_mass_balance_flux');
%netcdf.putAtt(ncid, acab_id, 'units', 'kg m-2 year-1');
%netcdf.putAtt(ncid, artm_id, 'long_name', 'Annual Mean Air Temperature (2 meter)');
%netcdf.putAtt(ncid, artm_id, 'standard_name', 'air_temperature');
%netcdf.putAtt(ncid, artm_id, 'grid_mapping', 'mapping');
%netcdf.putAtt(ncid, artm_id, 'units', 'Kelvin');

netcdf.putAtt(ncid, bhf_id, 'grid_mapping', 'mapping');
netcdf.putAtt(ncid, bhf_id, 'long_name', 'Basal Heat Flux');
netcdf.putAtt(ncid, bhf_id, 'units', 'watts/meter^2');
% netcdf.putAtt(ncid, tillwat_id, 'units', 'm');
% netcdf.putAtt(ncid, tillwat_id, 'standard_name', 'till_water_thickness');
% netcdf.putAtt(ncid, ubc_id, 'units', 'm year-1');
% netcdf.putAtt(ncid, vbc_id, 'units', 'm year-1');
% netcdf.putAtt(ncid, bwat_id, 'units', 'm');
netcdf.putAtt(ncid, tillphi_id, 'grid_mapping', 'mapping');
netcdf.putAtt(ncid, tillphi_id, 'standard_name', 'till_phi');
netcdf.putAtt(ncid, tillphi_id, 'pism_intent', 'model_state');
netcdf.putAtt(ncid, tillphi_id, 'units', 'degrees');

netcdf.putAtt(ncid,lat_id,'grid_mapping','mapping');
netcdf.putAtt(ncid,lat_id,'long_name','Latitude');
netcdf.putAtt(ncid,lat_id,'standard_name','latitude');
netcdf.putAtt(ncid,lat_id,'units','degreeN');
netcdf.putAtt(ncid,lon_id,'grid_mapping','mapping');
netcdf.putAtt(ncid,lon_id,'long_name','Longitude');
netcdf.putAtt(ncid,lon_id,'standard_name','longitude');
netcdf.putAtt(ncid,lon_id,'units','degreeN');

netcdf.putAtt(ncid, cmba_id, 'units', 'kg m-2 year-1');
netcdf.putAtt(ncid, cmba_id, 'grid_mapping', 'mapping');
netcdf.putAtt(ncid, cmba_id, 'long_name', 'Surface Mass Balance Anomaly');
netcdf.putAtt(ncid, cmba_id, 'standard_name', 'land_ice_surface_specific_mass_balance_flux');
netcdf.putAtt(ncid, cmba_id, 'units', 'kg m-2 year-1');
netcdf.putAtt(ncid, ista_id, 'grid_mapping', 'mapping');
netcdf.putAtt(ncid, ista_id, 'long_name', 'Annual Mean Air Temperature Anomaly');
netcdf.putAtt(ncid, ista_id, 'standard_name', 'air_temperature_anomaly');
netcdf.putAtt(ncid, ista_id, 'units', 'Kelvin');

%netcdf.putAtt(ncid, cmba_id, 'units', 'kg m-2 year-1');
%netcdf.putAtt(ncid, cmba_id, 'standard_name', 'climatic_mass_balance_anomaly');
%netcdf.putAtt(ncid, ista_id, 'units', 'Kelvin');
%netcdf.putAtt(ncid, ista_id, 'standard_name', 'ice_surface_temp_anomaly');








netcdf.close(ncid);
