#! /bin/bash


# make a proper distribution file

# contains the geology

sed_composition_file=composition.nc
sed_distribution_file=thickness.nc

filter_width=40 # in km
filter_type=m



# lambert projection parameters, which is the projection of the original maps
lon0=-95
lat0=49
lat1=49
lat2=77
width=15c

JL_options=${lon0}/${lat0}/${lat1}/${lat2}/${width}

east_latitude=58.97436709044697
east_longitude=-8.956961274206426
west_latitude=26.53376749137807
west_longitude=-134.7161085963003

#R_options2="-Re-4273300.3539000004529953/-1276162.9283999986946583/3476699.6460999995470047/3883837.0716000013053417"
#R_options_L="-R${west_longitude}/${west_latitude}/${east_longitude}/${east_latitude}r"

		
		
east_latitude=58.5615041007
east_longitude=1.68574761329
west_latitude=26.7886501009
west_longitude=-131.719605173

R_options2="-Re-3964875.08667/-1441149.85907/3595124.91334/4463850.14093"
R_options_L="-R${west_longitude}/${west_latitude}/${east_longitude}/${east_latitude}r"

# grid choices





# distribution, currently set up to be represented by the "maximum till water thickness"

blanket=1
blanket_thickness=0.5
#blanket_thickness=0.1

rock=2
rock_thickness=4.0
#rock_thickness=1.0

veneer=3
#veneer_thickness=0.5 
veneer_thickness=2.0 # this is the pism default value

otherdist=4
otherdist_thickness=2.0 # this is the pism default value
otherdist_thickness=0.5 # this is the pism default value

thickness_scale=

# For Albers projection of the final grid

center_longitude=-108
center_latitude=61
resolution=50000 # grid resolution, in metres!

# corner points of the grid (if we don't use this, gmt assumes a global grid, which will be huge!
# west corresponds to the bottom left corner, east corresponds to the top right corner
# probably easiest to pick off the cordinates off Google Earth, in a really zoomed out view
west_latitude=36
west_longitude=-130
east_latitude=50
east_longitude=-10


J_options="-Ja${center_longitude}/${center_latitude}/1:${resolution}"
R_options="-R${west_longitude}/${west_latitude}/${east_longitude}/${east_latitude}r"

# for Polar Stereographic final grid, what I assume is used in Lu's setup
# Projection #3413

# 3413 was the wrong projection, actually centered at 90 degrees N
latitude_of_origin=90
central_meridian=-45

resolution=${filter_width}000 # grid resolution, in metres!

#    PARAMETER["scale_factor",1],
#    PARAMETER["false_easting",0],
#    PARAMETER["false_northing",0],
#    AUTHORITY["EPSG","3413"],

J_options="-JS${central_meridian}/${latitude_of_origin}/${width}"

xmin=-5980000
xmax=5980000 #,10000)
ymin=-5980000
ymax=5980000 #,10000)

R_options="-R${xmin}/${xmax}/${ymin}/${ymax}"

# the grid resolution for input into PISM. I think it can be defined as rectangular, so the x and y resolutions can be defined differently. In metres!
x_resolution=50000
y_resolution=50000

xtext="x"

xtickint=2000000
xsubtickint=1000000

ytext="y"

ytickint=2000000
ysubtickint=1000000

for file_type in composition distribution geology
do

# convert to geographic projection

	file_name=${file_type}.nc
	echo  ${file_type}.nc
#
	grd2xyz ${file_type}.nc | awk '{if($3 == "NaN") {print $1, $2, 255} else {print $1, $2, $3}}' | mapproject  -JL${JL_options} ${R_options2} -I -F -C > ${file_type}_temp.ll
		

# convert values to shear friction angle for PISM

	if [ "${file_type}" == "distribution" ]
	then

		blanket=1
		blanket_angle=10
    blanket_percent=1

		rock=2
		rock_angle=30
    rock_percent=0.5


		veneer=3
		veneer_angle=20 
    veneer_percent=0.95


		othercomp=4
		othercomp_angle=30 # pism default value
    othercomp_percent=0.95


		awk --field-separator '\t' -v blanket=${blanket} -v blanket_angle=${blanket_angle} -v rock=${rock} -v rock_angle=${rock_angle} -v veneer=${veneer} -v veneer_angle=${veneer_angle} -v othercomp=${othercomp} -v othercomp_angle=${othercomp_angle} '{if ($3 == blanket) {print $1, $2, blanket_angle} else if($3 == rock) {print $1, $2, rock_angle} else if($3 == veneer) {print $1, $2, veneer_angle} else {print $1, $2, othercomp_angle}}' ${file_type}_temp.ll > ${file_type}_temp2.ll


		awk --field-separator '\t' -v blanket=${blanket} -v blanket_percent=${blanket_percent} -v rock=${rock} -v rock_percent=${rock_percent} -v veneer=${veneer} -v veneer_percent=${veneer_percent} -v othercomp=${othercomp} -v othercomp_percent=${othercomp_percent} '{if ($3 == blanket) {print $1, $2, blanket_percent} else if($3 == rock) {print $1, $2, rock_percent} else if($3 == veneer) {print $1, $2, veneer_percent} else {print $1, $2, othercomp_percent}}' ${file_type}_temp.ll > ${file_type}_cover_temp2.ll

		noval=${othercomp_angle}
		noval_percent=${othercomp_percent}


	elif  [ "${file_type}" == "composition" ]
	then

		clay=1
		clay_angle=15

		sand=2
		sand_angle=30

		silt=3
		silt_angle=23

		othercomp=4
		othercomp_angle=30 # pism default value

		awk --field-separator '\t' -v sand=${sand} -v sand_angle=${sand_angle} -v clay=${clay} -v clay_angle=${clay_angle} -v silt=${silt} -v silt_angle=${silt_angle} -v othercomp=${othercomp} -v othercomp_angle=${othercomp_angle} '{if ($3 == sand) {print $1, $2, sand_angle} else if($3 == clay) {print $1, $2, clay_angle} else if($3 == silt) {print $1, $2, silt_angle} else {print $1, $2, othercomp_angle}}' ${file_type}_temp.ll > ${file_type}_temp2.ll

		noval=${othercomp_angle}


	elif  [ "${file_type}" == "geology" ]
	then


		sedimentary=0
		sedimentary_angle=10

		felsic_plutonic=1
		felsic_plutonic_angle=30

		felsic_volcanic=2
		felsic_volcanic_angle=25

		mafic_plutonic=3
		mafic_plutonic_angle=30

		mafic_volcanic=4
		mafic_volcanic_angle=25

		low_grade_metamorphic=5
		low_grade_metamorphic_angle=20 


		high_grade_metamorphic=6
		high_grade_metamorphic_angle=30 


		othercomp=4
		othercomp_angle=30 # pism default value


		awk --field-separator '\t' -v sedimentary=${sedimentary} -v sedimentary_angle=${sedimentary_angle} -v felsic_plutonic=${felsic_plutonic} -v felsic_plutonic_angle=${felsic_plutonic_angle}  -v felsic_volcanic=${felsic_volcanic} -v felsic_volcanic_angle=${felsic_volcanic_angle} -v mafic_plutonic=${mafic_plutonic} -v mafic_plutonic_angle=${mafic_plutonic_angle}  -v mafic_volcanic=${mafic_volcanic} -v mafic_volcanic_angle=${mafic_volcanic_angle} -v low_grade_metamorphic=${low_grade_metamorphic} -v low_grade_metamorphic_angle=${low_grade_metamorphic_angle}  -v high_grade_metamorphic=${high_grade_metamorphic} -v high_grade_metamorphic_angle=${high_grade_metamorphic_angle}  -v othercomp=${othercomp} -v othercomp_angle=${othercomp_angle} '{if ($3 == sedimentary) {print $1, $2, sedimentary_angle} else if($3 == felsic_plutonic) {print $1, $2, felsic_plutonic_angle} else if($3 == felsic_volcanic) {print $1, $2, felsic_volcanic_angle}  else if($3 == mafic_plutonic) {print $1, $2, mafic_plutonic_angle} else if($3 == mafic_volcanic) {print $1, $2, mafic_volcanic_angle}  else if($3 == low_grade_metamorphic) {print $1, $2, low_grade_metamorphic_angle}   else if($3 == high_grade_metamorphic) {print $1, $2, high_grade_metamorphic_angle} else {print $1, $2, othercomp_angle}}' ${file_type}_temp.ll > ${file_type}_temp2.ll

		noval=${othercomp_angle}


	fi

	makecpt -Cjet -T14/40/2 > ${file_type}_shades.cpt

	x_name=x
	y_name=y
	z_name_short="tillphi"
	z_name="${z_name_short} [degrees]" # always include units
	z_scale="1"
	z_offset="0" # applied after scaling
	z_invalid="0" # value for areas without data
	title="phi" # title for the data
	remark="friction angle for till under grounded ice sheet"
	units="degrees"

	scale=10

	remove_nan=${othercomp_angle}



	mapproject ${file_type}_temp2.ll ${R_options} ${J_options} -C -Fe | awk '{print $1, $2, $3}'  > ${file_type}_temp.xyz


	xyz2grd ${file_type}_temp.xyz -G${file_type}_temp.nc ${R_options} -I${resolution}=  -D${x_name}/${y_name}/"${z_name}"/${z_scale}/${z_offset}/${z_invalid}/"${title}"/"${remark}" 

	grdmath ${file_type}_temp.nc ${remove_nan} DENAN = ${file_type}_polar.nc

	ncrename -O -v z,${z_name_short}  ${file_type}_polar.nc
	ncatted -O -a units,x,o,c,"m" ${file_type}_polar.nc
	ncatted -O -a units,y,o,c,"m" ${file_type}_polar.nc

	ncatted -O -a axis,x,o,c,"X" ${file_type}_polar.nc
	ncatted -O -a axis,y,o,c,"Y" ${file_type}_polar.nc


	ncap -O -s 'tillphi=double(tillphi)' ${file_type}_polar.nc ${file_type}_double.nc

	ncatted -O -a long_name,tillphi,o,c,"friction angle for till under grounded ice sheet" ${file_type}_double.nc
	ncatted -O -a units,tillphi,o,c,"degrees" ${file_type}_double.nc
	ncatted -O -a pism_intent,tillphi,o,c,"model_state" ${file_type}_double.nc


	plot=${file_type}.ps
	makecpt -Cwysiwyg -T6/34/2 -V > ${file_type}_shades.cpt
	grdimage  -Y10 ${file_type}_double.nc -JX15c/0 -K -P -C${file_type}_shades.cpt -V -nb > ${plot}
	pscoast ${R_options} ${J_options}  -Bafg -O -K -P -Wthin -Di -A5000 >> ${plot}

	psscale -Y-4 -X-4 -Dx9c/2c/9c/0.5ch  -O -J -R -Ba${scale}:"${z_name}":/:: -C${file_type}_shades.cpt   >> ${plot}



	if [ "${file_type}" == "distribution" ]
	then
    
	  x_name=x
	  y_name=y
	  z_name_short="tillcover"
	  z_name="${z_name_short} [1]" # always include units
	  z_scale="1"
	  z_offset="0" # applied after scaling
	  z_invalid="0" # value for areas without data
	  title="phi" # title for the data
	  remark="fraction of surface that is covered in till"
	  units="1"




	  mapproject ${file_type}_cover_temp2.ll ${R_options} ${J_options} -C -Fe | awk '{print $1, $2, $3}'  > ${file_type}_temp.xyz


	  xyz2grd ${file_type}_temp.xyz -G${file_type}_temp.nc ${R_options} -I${resolution}=  -D${x_name}/${y_name}/"${z_name}"/${z_scale}/${z_offset}/${z_invalid}/"${title}"/"${remark}" 

	  remove_nan=${othercomp_percent}

	  grdmath ${file_type}_temp.nc ${remove_nan} DENAN = ${file_type}_cover_polar.nc

	  ncrename -O -v z,${z_name_short}  ${file_type}_cover_polar.nc
	  ncatted -O -a units,x,o,c,"m" ${file_type}_cover_polar.nc
	  ncatted -O -a units,y,o,c,"m" ${file_type}_cover_polar.nc

	  ncatted -O -a axis,x,o,c,"X" ${file_type}_cover_polar.nc
	  ncatted -O -a axis,y,o,c,"Y" ${file_type}_cover_polar.nc


	  ncap -O -s 'tillcover=double(tillcover)' ${file_type}_cover_polar.nc ${file_type}_cover_double.nc

	  ncatted -O -a long_name,tillcover,o,c,"friction angle for till under grounded ice sheet" ${file_type}_cover_double.nc
	  ncatted -O -a units,tillcover,o,c,"1" ${file_type}_cover_double.nc
	  ncatted -O -a pism_intent,tillcover,o,c,"model_state" ${file_type}_cover_double.nc



  fi


done
